@@ -37,7 +37,6 @@
 
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
-#include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
@@ -71,6 +70,42 @@ public:
   }
 };
 
+class PackageTable : public Lum::Model::StdTable<PackageEntry>
+{
+public:
+  class PackageDataProvider : public Lum::Model::StdTable<PackageEntry>::DataProvider
+  {
+    std::wstring GetString(const PackageTable::Iterator& iter, size_t column) const
+    {
+      return iter->GetString(column);
+    }
+
+    Lum::Object* GetObject(const PackageTable::Iterator& iter, size_t column) const
+    {
+      return iter->GetObject(column);
+    }
+  };
+
+  class PackageComparator : public Lum::Model::StdTable<PackageEntry>::Comparator
+  {
+  public:
+    bool operator()(const PackageEntry& a, const PackageEntry& b, size_t column, bool down) const
+    {
+      return a.GetPackage()->GetName()<b.GetPackage()->GetName();
+    }
+  };
+
+public:
+  PackageTable()
+  : Lum::Model::StdTable<PackageEntry>(new PackageDataProvider(),
+                                       new PackageComparator())
+  {
+    // no code
+  }
+};
+
+typedef Lum::Base::Reference<PackageTable> PackageTableRef;
+
 class MainDialog : public Lum::Dialog
 {
 private:
@@ -81,7 +116,7 @@ private:
   std::wstring                       lastSearch;
   Lum::Model::StringRef              search;
   Lum::Model::ActionRef              searchTimerAction;
-  Lum::Model::ListTableRef           currentPackages;
+  PackageTableRef                    currentPackages;
   Lum::Model::SingleLineSelectionRef selection;
   PackageListTask                    packageListTask;
 
@@ -92,7 +127,7 @@ public:
     aboutAction(new Lum::Model::Action()),
     search(new Lum::Model::String(L"")),
     searchTimerAction(new Lum::Model::Action()),
-    currentPackages(new Lum::Model::ListTable(1)),
+    currentPackages(new PackageTable()),
     selection(new Lum::Model::SingleLineSelection()),
     packageListTask(packages)
   {
@@ -115,34 +150,20 @@ public:
 
   virtual void PreInit()
   {
-    Lum::Button           *button;
     Lum::Panel            *vpanel,*hpanel;
-    Lum::String           *string;
     Lum::Table            *table;
     Lum::Model::HeaderRef headerModel;
 
-    vpanel=new Lum::VPanel();
-    vpanel->SetFlex(true,true);
-
-    hpanel=new Lum::HPanel();
-    hpanel->SetFlex(true,false);
+    vpanel=Lum::VPanel::Create(true,true);
 
+    hpanel=Lum::HPanel::Create(true,false);
     hpanel->Add(new Lum::Text(L"Filter:"));
-
-    hpanel->Add(new Lum::HSpace());
-
-    string=new Lum::String();
-    string->SetFlex(true,false);
-    string->SetModel(search);
-    hpanel->Add(string);
-
-    button=new Lum::Button(L"_Clear");
-    button->SetFlex(false,true);
-    button->SetModel(clearFilterAction);
-    hpanel->Add(button);
+    hpanel->AddSpace();
+    hpanel->Add(Lum::String::Create(search,true,false));
+    hpanel->Add(Lum::Button::Create(L"_Clear",clearFilterAction,false,true));
 
     vpanel->Add(hpanel);
-    vpanel->Add(new Lum::VSpace());
+    vpanel->AddSpace();
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Package",Lum::Base::Size::stdCharWidth,28,true);
@@ -223,11 +244,11 @@ public:
          iter!=packages.end();
          ++iter) {
       if (search.empty() || iter->GetName().find(search)!=std::wstring::npos) {
-        currentPackages->Append(new PackageEntry(currentPackages,&(*iter)));
+        currentPackages->Append(PackageEntry(&(*iter)));
       }
     }
 
-    currentPackages->Sort(1);
+    currentPackages->Sort(1,true);
     currentPackages->On();
     currentPackages->Enable();
   }
@@ -245,7 +266,7 @@ public:
       UpdateEntries();
     }
     else if (model==showPackageAction && showPackageAction->IsFinished()) {
-      Package*       package=dynamic_cast<PackageEntry*>(currentPackages->GetEntry(selection->GetLine()))->GetPackage();
+      Package*       package=currentPackages->GetEntry(selection->GetLine()).GetPackage();
       PackageDetails *dialog;
 
       dialog=new PackageDetails(*package);
