@@ -22,12 +22,15 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Model/Header.h>
+#include <Lum/Model/Table.h>
+
 #include <Lum/ButtonRow.h>
 #include <Lum/Edit/Edit.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/Tab.h>
+#include <Lum/Table.h>
 #include <Lum/Text.h>
 #include <Lum/View.h>
 
@@ -50,51 +53,75 @@ Lum::Object* PackageDetails::GetTextField(const std::wstring& text) const
 
 void PackageDetails::PreInit()
 {
-  Lum::ButtonRow  *row;
-  Lum::Edit::Edit *edit;
-  Lum::Edit::Text *editContent;
-  Lum::Panel      *vPanel;
-  Lum::Tab        *tab;
-  Lum::View       *view;
+  Lum::Edit::Edit             *edit;
+  Lum::Edit::Text             *editContent;
+  Lum::Panel                  *vPanel;
+  Lum::Model::HeaderRef       headers;
+  Lum::Model::StringMatrixRef headerList;
+  std::vector<std::wstring>   header;
+  Lum::Tab                    *tab;
+  Lum::Table                  *table;
 
-  vPanel=new Lum::VPanel();
-  vPanel->SetFlex(true,true);
+  vPanel=Lum::VPanel::Create(true,true);
 
-  tab=new Lum::Tab();
-  tab->SetFlex(true,true);
+  tab=Lum::Tab::Create(true,true);
 
-  editContent=new Lum::Edit::Text();
-  editContent->SetText(L"Package: "+package.GetName()+L" "+package.GetVersion()+ L" ("+package.GetSection()+L")\n"+
-                       L"Description: "+(package.GetShortDescription().empty() ? L"<no description>" : package.GetShortDescription())+L"\n"+
-                       L"Maintainer: "+(package.GetMaintainer().empty() ? L"<no maintainer>" : package.GetMaintainer())+L"\n"+
-                       L"Homepage: "+(package.GetHomepage().empty() ? L"<no homepage> " : package.GetHomepage())+L"\n"+
-                       L"Size (deb/inst.): "+Lum::Base::NumberToWString(package.GetPackageSize())+L"/"+
-                  Lum::Base::NumberToWString(package.GetInstalledSize()));
-  editContent->Disable();
+  headerList=new Lum::Model::StringMatrix();
 
-  view=new Lum::View();
-  view->SetFlex(true,true);
+  header.clear();
+  header.push_back(L"Package");
+  header.push_back(package.GetName());
+  headerList->Append(header);
 
-  edit=new Lum::Edit::Edit();
-  edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
-  edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
-  edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
-  edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
-  edit->SetFont(Lum::OS::display->GetFont());
-  edit->SetModel(editContent);
+  header.clear();
+  header.push_back(L"Version");
+  header.push_back(package.GetVersion());
+  headerList->Append(header);
 
-  view->SetObject(edit);
+  header.clear();
+  header.push_back(L"Section");
+  header.push_back(package.GetSection());
+  headerList->Append(header);
 
-  tab->Add(L"Data",view);
+  header.clear();
+  header.push_back(L"Description");
+  header.push_back((package.GetShortDescription().empty() ? L"<no description>" : package.GetShortDescription()));
+  headerList->Append(header);
+
+  header.clear();
+  header.push_back(L"Maintainer");
+  header.push_back((package.GetMaintainer().empty() ? L"<no maintainer>" : package.GetMaintainer()));
+  headerList->Append(header);
+
+  header.clear();
+  header.push_back(L"Package size");
+  header.push_back(Lum::Base::NumberToWString(package.GetPackageSize())+L" bytes");
+  headerList->Append(header);
+
+
+  header.clear();
+  header.push_back(L"Install size");
+  header.push_back(Lum::Base::NumberToWString(package.GetInstalledSize())+L" bytes");
+  headerList->Append(header);
+
+  headers=new Lum::Model::HeaderImpl();
+  headers->AddColumn(L"Data",Lum::Base::Size::stdCharWidth,15);
+  headers->AddColumn(L"Value",Lum::Base::Size::stdCharWidth,20,true);
+
+  table=new Lum::Table();
+  table->SetFlex(true,true);
+  table->SetShowHeader(true);
+  table->GetTableView()->SetAutoHSize(true);
+  table->GetTableView()->SetAutoFitColumns(true);
+  table->SetHeaderModel(headers);
+  table->SetModel(headerList);
+
+  tab->Add(L"Data",table);
 
   editContent=new Lum::Edit::Text();
   editContent->SetText(package.GetDescription());
   editContent->Disable();
 
-  view=new Lum::View();
-  view->SetFlex(true,true);
-
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
   edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
@@ -104,17 +131,23 @@ void PackageDetails::PreInit()
   edit->SetFont(Lum::OS::display->GetFont());
   edit->SetModel(editContent);
 
-  view->SetObject(edit);
+  tab->Add(L"Description",Lum::View::Create(edit,true,true));
 
-  tab->Add(L"Description",view);
+  table=new Lum::Table();
+  table->SetFlex(true,true);
+
+  if (package.LoadPackageContent(files)) {
+    Lum::Model::StringRefTableRef filesModel=new Lum::Model::StringRefTable(files);
+
+    table->SetModel(filesModel);
+  }
+
+  tab->Add(L"Content",table);
 
   editContent=new Lum::Edit::Text();
   editContent->SetText(package.GetDependencies());
   editContent->Disable();
 
-  view=new Lum::View();
-  view->SetFlex(true,true);
-
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
   edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
@@ -124,17 +157,11 @@ void PackageDetails::PreInit()
   edit->SetFont(Lum::OS::display->GetFont());
   edit->SetModel(editContent);
 
-  view->SetObject(edit);
-
-  tab->Add(L"Dependencies",view);
+  tab->Add(L"Dependencies",Lum::View::Create(edit,true,true));
 
   vPanel->Add(tab);
-
-  vPanel->Add(new Lum::VSpace());
-
-  row=Lum::ButtonRow::CreateClose(GetClosedAction());
-  row->SetFlex(true,false);
-  vPanel->Add(row);
+  vPanel->AddSpace();
+  vPanel->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
 
   SetMain(vPanel);
 
